#!/bin/bash
# Sets up a new Training project based on SSDT default configuration in the current working directory.
#
# Usage:
#
#  /data/preview/training-01 $   /ssdt/compose2/prod/training.sh
#
# Will create a docker-compose.yml and .env file with default settings using the SSDT 
# supplied training database
#
# These are special database images which recreates the database each time the container is started.
# Therefore, it is very easy to reset the training database simply deleting and restarting the containers. 
# For example:
#     
#    docker-compose down
#    docker-compose up -d
#
source "$(dirname "${BASH_SOURCE[0]}")/../scripts/.functions.sh"

md5calc() {
   md5sum ${1} ;
}

md5verify() {
   md5sum -c --status ${1} ;
}

genDBHash() {
 echo $(date +%s%N | sha256sum | base64 | head -c 32 ; echo)
}

base=$(dirname "${BASH_SOURCE[0]}")
default_name=$(basename $PWD)

args="$1$2"

usas=""
usps=""

if [ "$args" == "" ] || [ -z "${args##*usas*}" ]
then
   usas=1
fi

if [ "$args" == "" ] || [ -z "${args##*usps*}" ]
then
   usps=1
fi

echo "Preparing training project '$(basename $PWD)' with default USxS configuration" 

touch .env
source .env

project_name=${default_name}

if [ "$COMPOSE_PROJECT_NAME" == "" ]
then
   echo "COMPOSE_PROJECT_NAME=${project_name}" >> .env
   source .env
fi

if [ ! -e "docker-compose.yml" ] 
then 
   create="OK"
elif [ -e ".docker-compose.md5" ]; then
   md5verify ./.docker-compose.md5 && create="OK"
fi

if [ "$create" == "OK" ] 
then

    cat $base/training.yml > ./docker-compose.yml
    echo "" >> ./docker-compose.yml

    md5calc ./docker-compose.yml > .docker-compose.md5

    echo "created docker-compose.yml for training instance ${project_name}"
  
else
    echo "
    
    Error! docker-compose.yml file has been modified or checksum missing.  Can not auto-apply update(s).
           Move customizations to docker-compose.override.yml then delete the docker-compose.yml
"
fi
    
if [ ! -e "docker-compose.override.yml" ] 
then 
   echo 'version: "3.3"' >> docker-compose.override.yml   
fi
    
if [ "$USAS_APPLICATIONID" == "" ]
then
     usas_id=${COMPOSE_PROJECT_NAME}-usas
     usas_key=$(openssl rand -hex 32)
     usps_id=${COMPOSE_PROJECT_NAME}-usps
     usps_key=$(openssl rand -hex 32)
     echo "USAS_APPLICATIONID=${usas_id}"   >> .env
     echo "USAS_APIKEY=$usas_key"           >> .env
     echo "USPS_APPLICATIONID=${usps_id}"   >> .env
     echo "USPS_APIKEY=$usps_key"           >> .env
     echo "Created integration API keys.  Enable integration modules after applications start"
fi

if [ "$USAS_APP_HOST" == "" ]
then
   echo "USAS_APP_HOST=usasapp-svr"   >> .env
fi

if [ "$USPS_APP_HOST" == "" ]
then
   echo "USPS_APP_HOST=uspsapp-svr"   >> .env
fi

echo "Review or create docker-compose.override.yml for custom settings."

